==> haskell-httpd-shed-0.4.1.2-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-AEZtQkyo2x8EIVs2sYL9Bh
key:                  httpd-shed-0.4.1.2-AEZtQkyo2x8EIVs2sYL9Bh
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  81fc62bbb3b22f129da8a53b14529a67
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-AEZtQkyo2x8EIVs2sYL9Bh
depends:
    base-4.17.2.1 network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    network-bsd-2.8.1.0-BJUSKEuJTGy8j4ZDnoY4NB
    network-uri-2.6.4.2-BPG1Yj05GAIIauIotQ4jTb

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.2-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-Gp6VS9k2cgz3u70NYX2VR6
key:                  httpd-shed-0.4.1.2-Gp6VS9k2cgz3u70NYX2VR6
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  43ff5a95d74f9e93ac37271d49883826
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-Gp6VS9k2cgz3u70NYX2VR6
depends:
    base-4.17.2.1 network-3.1.4.0-1eoJcyQnoY08famP5jSKP3
    network-bsd-2.8.1.0-2Idz5QPbLS37FO0cfIbqZZ
    network-uri-2.6.4.2-4dyZiFqUsAXDJ8mS3jtc8B

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
